/**
 * Este software pertenece a Cajamar Caja Rural Sociedad Cooperativa de Crdito. Se prohbe todo uso
 * y/o explotacin del software que no cuente con la autorizacin expresa por escrito de Cajamar
 * Caja Rural Sociedad Cooperativa de Crdito. Todos los derechos se encuentran reservados.
 */

package zk.test;

import java.util.Iterator;
import java.util.List;
import java.util.Set;
import java.util.logging.Logger;

import org.zkoss.zul.DefaultTreeModel;
import org.zkoss.zul.Label;
import org.zkoss.zul.Tree;
import org.zkoss.zul.TreeNode;
import org.zkoss.zul.event.TreeDataEvent;
import org.zkoss.zul.event.TreeDataListener;

/**
 * @author fcf60478
 */
public final class EgiptoElementSelectTreeDataListener implements TreeDataListener {

    /**Atributo que indica que el */
    private static final String SEL_NOD_ACT = "selection_node_active";

    /** PDS_SCROLLVIEW*/
    private static final int POS_SCROLLVIEW = 5;

    /**Logger*/
    private Logger logger = Logger.getLogger(getClass().getName());
    /**
     * Referencia al Tree
     */
    private Tree treeEgipto = null;

    /** Etiqueta en la que se escriben los ttoales */
    private Label total;

    /**
     * Constructor por defecto
     * 
     * @param tree
     *            Una referencia al tree necesario para refrescar la vista
     * @param selectedCount
     *            Etiqueta en la que se ponen los totales
     */
    public EgiptoElementSelectTreeDataListener(final Tree tree, final Label selectedCount) {
        super();
        logger.severe("Logger Creado");
        this.treeEgipto = tree;
        this.total = selectedCount;
    }

    /*
     * (non-Javadoc)
     * @see org.zkoss.zul.event.TreeDataListener#onChange(org.zkoss.zul.event.TreeDataEvent)
     */
    @Override
    public void onChange(final TreeDataEvent event) {
        logger.severe("Event caught: "+event.getType());
        logger.severe("                  : "+ event.getType()+" == "+TreeDataEvent.SELECTION_CHANGED);
        if (event.getType() == TreeDataEvent.SELECTION_CHANGED
) {
            logger.severe("     OK          : "+ event.getType()+" == "+TreeDataEvent.SELECTION_CHANGED);
        }

    }

    /**
     * Selecciona o Deselecciona de forma recursiva uan lista de TreeNode
     * 
     * @param tree
     *            El arbol de egipto
     * @param children
     *            La lista de nodo hijos
     * @param select
     *            true para seleccionar, false para deseleccionar
     * @param pos
     *            Posicin o contador del nodo visitado
     * @return La posicion del nodo 5 en el arbol
     */
    public int[] doSelect(Tree tree, List<?> children, boolean select, int[] pos) {
        int[] path = null;
        for (Iterator<?> it = children.iterator(); it.hasNext();) {
            TreeNode<?> node = (TreeNode<?>) it.next();
            int[] pathChild = getPathTreeNode(node);
            if (select) {
                node.getModel().addSelectionPath(pathChild);
            } else {
                node.getModel().removeSelectionPath(pathChild);
            }
            pos[0]++;
            if (pos[0] < POS_SCROLLVIEW) {
                path = pathChild;
            }
            if (!node.isLeaf()) {
                // selecciono de forma recursiva
                int[] newPath = doSelect(tree, node.getChildren(), select, pos);
                if (newPath != null) {
                    path = newPath;
                }
            }
        }

        return path;
    }

    /**
     * Obtiene el path de un treeNode
     * 
     * @param treeNode
     *            Un objeto de tipo TreeNode
     * @return un array de enteros con el path del nodo
     */
    @SuppressWarnings({ "rawtypes", "unchecked" })
    public int[] getPathTreeNode(TreeNode<?> treeNode) {
        return treeNode.getModel().getPath((TreeNode) treeNode);
    }

}
