/**
 * Este software pertenece a Cajamar Caja Rural Sociedad Cooperativa de Crdito. Se prohbe todo uso
 * y/o explotacin del software que no cuente con la autorizacin expresa por escrito de Cajamar
 * Caja Rural Sociedad Cooperativa de Crdito. Todos los derechos se encuentran reservados.
 */

package zk.test;

import org.zkoss.zul.DefaultTreeNode;
import org.zkoss.zul.Treecell;
import org.zkoss.zul.Treeitem;
import org.zkoss.zul.TreeitemRenderer;
import org.zkoss.zul.Treerow;

/**
 * @author dmg60561
 */
public final class EgiptoElementTreeitemRenderer implements
        TreeitemRenderer<DefaultTreeNode<EgiptoElement>> {

    /**
     * Numero de columnas que se expande la celda
     */
    private static final int COLUMN_CELLSPAN = 3;

    /**
     * 
     */
    private static final int PRIORITY_NEWVERSION = 100;

    /**
     * 
     */
    private static final int PRIORITY_NOTFOUND = 10;

    /**
     * Indica si permite versiones DEVEL-SHAPSHOT
     */
    private boolean allowSnapshots = true;

    /**
     * @param rightModel
     *            Modelo de datos de la derecha
     * @param allowSnapshots
     *            Indica si permite versiones DEVEL-SHAPSHOT
     */
    public EgiptoElementTreeitemRenderer() {
        super();
    }

    /**
     * Devuelve el color del Treerow dependiendo de la prioridad de este
     * 
     * @param priority
     *            Un entero con la prioridad
     * @return Una cadena con el color
     */
    private String getBGColorToTreerow(int priority) {
        String bgColor = "white";
        if (priority == PRIORITY_NOTFOUND) {
            // azulillo
            bgColor = "#EEEEFE";
        } else if (priority == PRIORITY_NEWVERSION) {
            // rojillo
            bgColor = "#FEEEEE";
        }
        return bgColor;
    }

    /**
     * @param item
     *            El treeitem
     * @param priority
     *            La prioridad a propagar hacia arriba en el arbol
     */
    private void propagateParentBgColor(Treeitem item, int priority) {
        // Prioridad intermedia entre filas
        int setPriority = priority;
        // Realizo la pasada desde abajo hacia arriba
        Treeitem parentItem = item.getParentItem();
        while (parentItem != null) {
            Treerow parentTreerow = parentItem.getTreerow();
            int prio = ((Integer) parentTreerow.getAttribute("priority")).intValue();
            if (prio < setPriority) {
                parentTreerow.setAttribute("priority", Integer.valueOf(setPriority));
                parentTreerow.setStyle("background: " + getBGColorToTreerow(setPriority));
            }
            parentItem = parentItem.getParentItem();
        }
    }

    /*
     * (non-Javadoc)
     * @see org.zkoss.zul.TreeitemRenderer#render(org.zkoss.zul.Treeitem, java.lang.Object, int)
     */
    @Override
    public void render(Treeitem item, DefaultTreeNode<EgiptoElement> data, int index)
            throws Exception { // NOSONAR
        String name = data.getData().getName();
        int priority = 0;
        Treerow row = new Treerow();

        item.appendChild(row);
        Treecell cell = new Treecell(name);
        row.appendChild(cell);
        cell.setTooltiptext(data.getData().getDescription());
        row.appendChild(cell);
        item.setValue(data.getData());
        cell.setSpan(COLUMN_CELLSPAN);
        row.setAttribute("priority", Integer.valueOf(priority));
        row.setStyle("background: " + getBGColorToTreerow(priority));

        // propaga la prioridad hacia arriba en el arbol
        propagateParentBgColor(item, priority);
    }

}
